@@ -27,7 +27,7 @@ class HighLine
     #
     # Create an instance of HighLine::Question.  Expects a _question_ to ask
     # (can be <tt>""</tt>) and an _answer_type_ to convert the answer to.
-    # The _answer_type_ parameter must be a type recongnized by
+    # The _answer_type_ parameter must be a type recognized by
     # Question.convert(). If given, a block is yeilded the new Question
     # object to allow custom initializaion.
     #
@@ -68,10 +68,9 @@ class HighLine
     attr_accessor :answer_type
     #
     # Can be set to +true+ to use HighLine's cross-platform character reader
-    # instead of fetching an entire line of input.  (Note: HighLine's
-    # character reader *ONLY* supports STDIN on Windows and Unix and may not
-    # work correctly if STDIN is redirected.)  Can also be set to <tt>:getc</tt>
-    # to use that method on the input stream.
+    # instead of fetching an entire line of input.  (Note: HighLine's character
+    # reader *ONLY* supports STDIN on Windows and Unix.)  Can also be set to
+    # <tt>:getc</tt> to use that method on the input stream.
     #
     # *WARNING*:  The _echo_ and _overwrite_ attributes for a question are 
     # ignored when using the <tt>:getc</tt> method.  
@@ -290,6 +289,7 @@ class HighLine
     # Pathname::               Same as File, save that a Pathname object is
     #                          returned.
     # String::                 Answer is converted with Kernel.String().
+    # HighLine::String::       Answer is converted with HighLine::String()
     # Regexp::                 Answer is fed to Regexp.new().
     # Symbol::                 The method to_sym() is called on answer and
     #                          the result returned.
@@ -302,6 +302,8 @@ class HighLine
     def convert( answer_string )
       if @answer_type.nil?
         answer_string
+      elsif @answer_type == HighLine::String
+        HighLine::String(answer_string)
       elsif [Float, Integer, String].include?(@answer_type)
         Kernel.send(@answer_type.to_s.to_sym, answer_string)
       elsif @answer_type == Symbol
